==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/sv.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Alla kalendrar är inte fullständigt sparade i cache",
"Everything seems to be completely cached" => "Allt verkar vara fullständigt sparat i cache",
"No calendars found." => "Inga kalendrar funna",
"No events found." => "Inga händelser funna.",
"Wrong calendar" => "Fel kalender",
"You do not have the permissions to edit this event." => "Du har inte behörighet att ändra denna händelse.",
"The file contained either no events or all events are already saved in your calendar." => "Filen innehöll inga händelser eller så är alla händelser redan sparade i kalendern.",
"events has been saved in the new calendar" => "händelser har sparats i den nya kalendern",
"Import failed" => "Misslyckad import",
"events has been saved in your calendar" => "händelse har sparats i din kalender",
"New Timezone:" => "Ny tidszon:",
"Timezone changed" => "Tidszon ändrad",
"Invalid request" => "Ogiltig begäran",
"Calendar" => "Kalender",
"Deletion failed" => "Raderingen misslyckades",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "Grupp",
"can edit" => "kan redigera",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"dddd, MMM d, yyyy" => "ddd, MMM d, yyyy",
"Sunday" => "Söndag",
"Monday" => "Måndag",
"Tuesday" => "Tisdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lördag",
"Sun." => "Sön.",
"Mon." => "Mån.",
"Tue." => "Tis.",
"Wed." => "Ons.",
"Thu." => "Tor.",
"Fri." => "Fre.",
"Sat." => "Lör.",
"January" => "Januari",
"February" => "Februari",
"March" => "Mars",
"April" => "April",
"May" => "Maj",
"June" => "Juni",
"July" => "Juli",
"August" => "Augusti",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Maj.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Hela dagen",
"New Calendar" => "Ny kalender",
"Missing or invalid fields" => "Saknade eller ogiltiga fält",
"Title" => "Rubrik",
"From Date" => "Från datum",
"From Time" => "Från tid",
"To Date" => "Till datum",
"To Time" => "Till tid",
"The event ends before it starts" => "Händelsen slutar innan den börjar",
"There was a database fail" => "Det blev ett databasfel",
"Birthday" => "Födelsedag",
"Business" => "Företag",
"Call" => "Ringa",
"Clients" => "Klienter",
"Deliverer" => "Leverantör",
"Holidays" => "Semester",
"Ideas" => "Idéer",
"Journey" => "Resa",
"Jubilee" => "Jubileum",
"Meeting" => "Möte",
"Other" => "Annat",
"Personal" => "Personlig",
"Projects" => "Projekt",
"Questions" => "Frågor",
"Work" => "Arbetet",
"by" => "av",
"unnamed" => "Namn saknas",
"You do not have the permissions to update this calendar." => "Du har inte behörighet att ändra denna kalender.",
"You do not have the permissions to delete this calendar." => "Du har inte behörighet att radera denna kalender.",
"You do not have the permissions to add to this calendar." => "Du har inte behörighet att lägga till denna kalender.",
"You do not have the permissions to add events to this calendar." => "Du har inte behörighet att lägga till händelser till denna kalender.",
"You do not have the permissions to delete this event." => "Du har inte behörighet att radera denna händelse.",
"Busy" => "Upptagen",
"Does not repeat" => "Upprepas inte",
"Daily" => "Dagligen",
"Weekly" => "Varje vecka",
"Every Weekday" => "Varje vardag",
"Bi-Weekly" => "Varannan vecka",
"Monthly" => "Varje månad",
"Yearly" => "Årligen",
"never" => "aldrig",
"by occurrences" => "efter händelser",
"by date" => "efter datum",
"by monthday" => "efter dag i månaden",
"by weekday" => "efter veckodag",
"events week of month" => "händelse vecka av månad",
"first" => "första",
"second" => "andra",
"third" => "tredje",
"fourth" => "fjärde",
"fifth" => "femte",
"last" => "sist",
"by events date" => "efter händelsedatum",
"by yearday(s)" => "efter årsdag(ar)",
"by weeknumber(s)" => "efter veckonummer",
"by day and month" => "efter dag och månad",
"Contact birthdays" => "Kontakters födelsedagar",
"Date" => "Datum",
"Cal." => "Kal.",
"Day" => "Dag",
"Week" => "Vecka",
"Month" => "Månad",
"Today" => "Idag",
"Settings" => "Inställningar",
"Share Calendar" => "Dela kalender",
"CalDav Link" => "CalDAV-länk",
"Download" => "Ladda ner",
"Edit" => "Redigera",
"Delete" => "Radera",
"New calendar" => "Nya kalender",
"Edit calendar" => "Redigera kalender",
"Displayname" => "Visningsnamn",
"Calendar color" => "Kalender-färg",
"Save" => "Spara",
"Submit" => "Lägg till",
"Cancel" => "Avbryt",
"Eventinfo" => "Händelseinfo",
"Repeating" => "Repetera",
"Alarm" => "Alarm",
"Attendees" => "Deltagare",
"Share" => "Dela",
"Title of the Event" => "Rubrik för händelsen",
"from" => "från",
"All Day Event" => "Hela dagen",
"Advanced options" => "Avancerade alternativ",
"Location" => "Plats",
"Edit categories" => "Redigera kategorier",
"Description" => "Beskrivning",
"Repeat" => "Upprepa",
"Advanced" => "Avancerad",
"Select weekdays" => "Välj veckodagar",
"Select days" => "Välj dagar",
"and the events day of year." => "och händelsedagen för året.",
"and the events day of month." => "och händelsedagen för månaden.",
"Select months" => "Välj månader",
"Select weeks" => "Välj veckor",
"and the events week of year." => "och händelsevecka för året.",
"Interval" => "Hur ofta",
"End" => "Slut",
"occurrences" => "Händelser",
"create a new calendar" => "skapa en ny kalender",
"Import a calendar file" => "Importera en kalenderfil",
"Please choose a calendar" => "Välj en kalender",
"Name of new calendar" => "Namn på ny kalender",
"Take an available name!" => "Ta ett ledigt namn!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "En kalender med detta namn finns redan. Om du fortsätter ändå så kommer dessa kalendrar att slås samman.",
"Remove all events from the selected calendar" => "Ta bort alla händelser från den valda kalendern",
"Import" => "Importera",
"Close Dialog" => "Stäng ",
"Create a new event" => "Skapa en ny händelse",
"Unshare" => "Sluta dela",
"Send Email" => "Skicka E-post",
"Shared via calendar" => "Delad via kalender",
"View an event" => "Visa en händelse",
"Category" => "Kategori",
"No categories selected" => "Inga kategorier valda",
"of" => "av",
"Access Class" => "Åtkomstklass",
"From" => "Från",
"at" => "på",
"To" => "Till",
"Your calendars" => "Dina kalendrar",
"General" => "Allmänt",
"Timezone" => "Tidszon",
"Update timezone automatically" => "Uppdatera tidzon automatiskt",
"Time format" => "Tidformat",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Starta veckan på",
"Cache" => "Cache",
"Clear cache for repeating events" => "Töm cache för upprepade händelser",
"URLs" => "URL:er",
"Calendar CalDAV syncing addresses" => "Kalender CalDAV synkroniserar adresser",
"more info" => "mer info",
"Primary address (Kontact et al)" => "Primary address (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Read only iCalendar link(s)"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/sv.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Alla kalendrar är inte fullständigt sparade i cache",
"Everything seems to be completely cached" => "Allt verkar vara fullständigt sparat i cache",
"No calendars found." => "Inga kalendrar funna",
"No events found." => "Inga händelser funna.",
"Wrong calendar" => "Fel kalender",
"You do not have the permissions to edit this event." => "Du har inte behörighet att ändra denna händelse.",
"The file contained either no events or all events are already saved in your calendar." => "Filen innehöll inga händelser eller så är alla händelser redan sparade i kalendern.",
"events has been saved in the new calendar" => "händelser har sparats i den nya kalendern",
"Import failed" => "Misslyckad import",
"events has been saved in your calendar" => "händelse har sparats i din kalender",
"New Timezone:" => "Ny tidszon:",
"Timezone changed" => "Tidszon ändrad",
"Invalid request" => "Ogiltig begäran",
"Calendar" => "Kalender",
"Deletion failed" => "Raderingen misslyckades",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "Grupp",
"can edit" => "kan redigera",
"can share" => "får dela",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ åååå]{ '–'[ MMM] d åååå}",
"dddd, MMM d, yyyy" => "ddd, MMM d, yyyy",
"Sunday" => "Söndag",
"Monday" => "Måndag",
"Tuesday" => "Tisdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lördag",
"Sun." => "Sön.",
"Mon." => "Mån.",
"Tue." => "Tis.",
"Wed." => "Ons.",
"Thu." => "Tor.",
"Fri." => "Fre.",
"Sat." => "Lör.",
"January" => "Januari",
"February" => "Februari",
"March" => "Mars",
"April" => "April",
"May" => "Maj",
"June" => "Juni",
"July" => "Juli",
"August" => "Augusti",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Maj.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Hela dagen",
"New Calendar" => "Ny kalender",
"Missing or invalid fields" => "Saknade eller ogiltiga fält",
"Title" => "Rubrik",
"From Date" => "Från datum",
"From Time" => "Från tid",
"To Date" => "Till datum",
"To Time" => "Till tid",
"The event ends before it starts" => "Händelsen slutar innan den börjar",
"There was a database fail" => "Det blev ett databasfel",
"Birthday" => "Födelsedag",
"Business" => "Företag",
"Call" => "Ring",
"Clients" => "Klienter",
"Deliverer" => "Leverantör",
"Holidays" => "Helgdagar",
"Ideas" => "Idéer",
"Journey" => "Resa",
"Jubilee" => "Jubileum",
"Meeting" => "Möte",
"Other" => "Annat",
"Personal" => "Personlig",
"Projects" => "Projekt",
"Questions" => "Frågor",
"Work" => "Arbetet",
"by" => "av",
"unnamed" => "Namn saknas",
"You do not have the permissions to update this calendar." => "Du har inte behörighet att ändra denna kalender.",
"You do not have the permissions to delete this calendar." => "Du har inte behörighet att radera denna kalender.",
"You do not have the permissions to add to this calendar." => "Du har inte behörighet att lägga till denna kalender.",
"You do not have the permissions to add events to this calendar." => "Du har inte behörighet att lägga till händelser till denna kalender.",
"You cannot add non-public events to a shared calendar." => "Du kan inte lägga till privata händelser till en delad kalender.",
"You do not have the permissions to delete this event." => "Du har inte behörighet att radera denna händelse.",
"Busy" => "Upptagen",
"Show full event" => "Visa hela händelsen",
"Show only busy" => "Visa endast upptagna",
"Hide event" => "Göm händelse",
"Does not repeat" => "Upprepas inte",
"Daily" => "Dagligen",
"Weekly" => "Varje vecka",
"Every Weekday" => "Varje vardag",
"Bi-Weekly" => "Varannan vecka",
"Monthly" => "Varje månad",
"Yearly" => "Årligen",
"never" => "aldrig",
"by occurrences" => "efter händelser",
"by date" => "efter datum",
"by monthday" => "efter dag i månaden",
"by weekday" => "efter veckodag",
"events week of month" => "händelse vecka i månad",
"first" => "första",
"second" => "andra",
"third" => "tredje",
"fourth" => "fjärde",
"fifth" => "femte",
"last" => "sist",
"by events date" => "efter händelsedatum",
"by yearday(s)" => "efter årsdag(ar)",
"by weeknumber(s)" => "efter veckonummer",
"by day and month" => "efter dag och månad",
"Contact birthdays" => "Kontakters födelsedagar",
"Date" => "Datum",
"Cal." => "Kal.",
"Day" => "Dag",
"Week" => "Vecka",
"Month" => "Månad",
"Today" => "Idag",
"CalDav Link" => "CalDAV-länk",
"Timezone" => "Tidszon",
"Update timezone automatically" => "Uppdatera tidzon automatiskt",
"Time format" => "Tidformat",
"24h" => "24tim",
"12h" => "12tim",
"Start week on" => "Starta veckan på",
"Cache" => "Cache",
"Clear cache for repeating events" => "Töm cache för upprepade händelser",
"Primary CalDAV address" => "Primär CalDAV adress",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV adress",
"Share Calendar" => "Dela kalender",
"Download" => "Ladda ner",
"Edit" => "Ändra",
"Delete" => "Ta bort",
"New calendar" => "Ny kalender",
"Edit calendar" => "Ändra kalender",
"Edit event" => "Redigera händelse",
"Save event" => "Spara händelse",
"Delete event" => "Ta bort händelse",
"Eventinfo" => "Händelseinfo",
"Repeating" => "Repetera",
"Alarm" => "Alarm",
"Attendees" => "Deltagare",
"Share" => "Dela",
"Title of the Event" => "Rubrik för händelsen",
"from" => "från",
"to" => "till",
"All Day Event" => "Heldags evenemang",
"Advanced options" => "Avancerade alternativ",
"Location" => "Plats",
"Categories (separate by comma)" => "Kategorier (kommaseparerade)",
"Edit categories" => "Redigera kategorier",
"Description" => "Beskrivning",
"Export event" => "Exportera händelse",
"Repeat" => "Upprepa",
"Advanced" => "Avancerad",
"Select weekdays" => "Välj veckodagar",
"Select days" => "Välj dagar",
"and the events day of year." => "och händelsedagen för året.",
"and the events day of month." => "och händelsedagen för månaden.",
"Select months" => "Välj månader",
"Select weeks" => "Välj veckor",
"and the events week of year." => "och händelsevecka för året.",
"Interval" => "Hur ofta",
"End" => "Slut",
"occurrences" => "Händelser",
"Visibility to people shared with" => "Synlighet för andra",
"create a new calendar" => "skapa en ny kalender",
"Import a calendar file" => "Importera en kalenderfil",
"Please choose a calendar" => "Välj en kalender",
"Name of new calendar" => "Namn på ny kalender",
"Take an available name!" => "Ta ett ledigt namn!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "En kalender med detta namn finns redan. Om du fortsätter ändå så kommer dessa kalendrar att slås samman.",
"Remove all events from the selected calendar" => "Ta bort alla händelser från den valda kalendern",
"Import" => "Importera",
"Close Dialog" => "Stäng ",
"Create a new event" => "Skapa en ny händelse",
"Create event" => "Skapa händelse",
"Share with user or group" => "Dela med användare eller grupp",
"Unshare" => "Sluta dela",
"Not shared with anyone" => "Delas inte med någon",
"Send Email" => "Skicka E-post",
"Shared via calendar" => "Delad via kalender",
"Not shared with anyone via calendar" => "Delas inte med någon via kalendern",
"View an event" => "Visa en händelse",
"Category" => "Kategori",
"No categories selected" => "Inga kategorier valda",
"%s of %s" => "%s av %s",
"Access Class" => "Åtkomstklass",
"From" => "Från",
"at" => "på",
"To" => "Till"
);
